Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Jsont.MetaAbstract syntax tree node metadata.
This type keeps information about source text locations and whitespace.
make textloc ~ws_before ~ws_after is metadata with text location textloc whitespace ws_before before the node and ws_after after the node. Both default to "".
val none : tnone is metadata for when there is none. Its textloc is Textloc.none and its whitespace is empty.
val ws_before : t -> stringws_before m is source whitespace before the node.
val ws_after : t -> stringws_after m is source whitespace after the node.
clear_textloc m is m with textloc set to Textloc.none.