Page
Library
Module
Module type
Parameter
Class
Class type
Jsont.ErrorSourceEncoding, decoding and query errors.
The type for kind of errors.
The type for errors. The context, the error localisation and the kind of error.
raise ctx meta k raises an error with given paramters.
make_msg ctx meta msg is an error with message msg for meta meta in context ctx.
msg meta msg raises an error with message msg for meta meta in an empty context.
msgf meta fmt … is like msg but formats an error message.
push_array kinded_sort n e contextualises e as an error in the nth element of an array of kinded sort kinded_sort.
push_object kinded_sort n e contextualises e as an error in the member n of an object of kinded sort kinded_sort.
adjust_context ~first_byte ~first_line adjusts the error's context's meta to encompass the given positions.